'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// 1xx
const INFORMATIONAL = {
    '100': 'Continue',
    '101': 'Switching Protocols',
    '102': 'Processing',
};
// 2xx
const SUCCESS = {
    '200': 'OK',
    '201': 'Created',
    '202': 'Accepted',
    '203': 'Non-authoritative Information',
    '204': 'No Content',
    '205': 'Reset Content',
    '206': 'Partial Content',
    '207': 'Multi-Status',
    '208': 'Already Reported',
    '209': 'IM Used',
};
// 3xx
const REDIRECTION = {
    '300': 'Multiple Choices',
    '301': 'Moved Permanently',
    '302': 'Found',
    '303': 'See Other',
    '304': 'Not Modified',
    '305': 'Use Proxy',
    '307': 'Temporary Redirect',
    '308': 'Permanent Redirect',
};
// 4xx
const CLIENT_ERROR = {
    '400': 'Bad Request',
    '401': 'Unauthorized',
    '402': 'Payment Required',
    '403': 'Forbidden',
    '404': 'Not Found',
    '405': 'Method Not Allowed',
    '406': 'Not Acceptable',
    '407': 'Proxy Authentication Required',
    '408': 'Request Timeout',
    '409': 'Conflict',
    '410': 'Gone',
    '411': 'Length Required',
    '412': 'Precondition Failed',
    '413': 'Payload Too Large',
    '414': 'Request-URI Too Long',
    '415': 'Unsupported Media Type',
    '416': 'Requested Range Not Satisfiable',
    '417': 'Expectation Failed',
    '418': "I'm a teapot",
    '421': 'Misdirected Request',
    '422': 'Unprocessable Entity',
    '423': 'Locked',
    '424': 'Failed Dependency',
    '426': 'Upgrade Required',
    '428': 'Precondition Required',
    '429': 'Too Many Requests',
    '431': 'Request Header Fields Too Large',
    '444': 'Connection Closed Without Response',
    '451': 'Unavailable For Legal Reasons',
    '499': 'Client Closed Request',
};
// 5xx
const SERVER_ERROR = {
    '500': 'Internal Server Error',
    '501': 'Not Implemented',
    '502': 'Bad Gateway',
    '503': 'Service Unavailable',
    '504': 'Gateway Timeout',
    '505': 'HTTP Version Not Supported',
    '506': 'Variant Also Negotiates',
    '507': 'Insufficient Storage',
    '508': 'Loop Detected',
    '510': 'Not Extended',
    '511': 'Network Authentication Required',
    '599': 'Network Connect Timeout Error',
};

/**
 * @function makeModelMessage
 *
 * Assemble the default message header.
 *
 * @param code - HTTP status code 1xx to 5xx
 * @param title - Short and descriptive information
 */
const makeModelMessage = ({ code, title }) => {
    const _code = Number(code);
    var _title;
    if (_code >= 100 && _code < 200) {
        _title = title !== null && title !== void 0 ? title : INFORMATIONAL[code];
    }
    else if (_code >= 200 && _code < 300) {
        _title = title !== null && title !== void 0 ? title : SUCCESS[code];
    }
    else if (_code >= 300 && _code < 400) {
        _title = title !== null && title !== void 0 ? title : REDIRECTION[code];
    }
    else if (_code >= 400 && _code < 500) {
        _title = title !== null && title !== void 0 ? title : CLIENT_ERROR[code];
    }
    else {
        _title = title !== null && title !== void 0 ? title : SERVER_ERROR[code];
    }
    return { title: _title, status: _code };
};

/**
 * @function makeRes
 *
 * Simple model for successful responses.
 *
 * @param code - HTTP status code 1xx to 3xx
 * @param message - Legible action response
 * @param data - Back Data
 * @param title - Short and descriptive information
 */
const makeRes = ({ code, data, message, title }) => Object.assign(makeModelMessage({ code, title }), { data, message });

/**
 * @function makeErr
 *
 * Creates an error response following the RFC 7807 pattern.
 *
 * @param code - HTTP status code 4xx to 5xx
 * @param type - URL for a document describing the error condition
 * @param detail - Legible error description
 * @param instance - URI exclusive for or specific error
 * @param title - Short and descriptive information
 */
const makeErr = ({ code, type = 'about:blank', title, detail, instance, }) => Object.assign(makeModelMessage({ code, title }), { type, detail, instance });

exports.makeErr = makeErr;
exports.makeRes = makeRes;
//# sourceMappingURL=index.js.map
